<?php
/*
  sassi.php
  2004/12/2
ǽ

ԡͭ²ҥɥ֥졼
δʿ
ryuhei@secondbrain.co.jp

  Released under the GNU General Public License
*/

define('MODULE_SHIPPING_SASSI_TEXT_TITLE', 'Ҿ͹ʪ');
define('MODULE_SHIPPING_SASSI_TEXT_DESCRIPTION', 'Ҿ͹ʪˤ');
define('MODULE_SHIPPING_SASSI_TEXT_WAY', 'Ҿ');
define('MODULE_SHIPPING_SASSI_TEXT_WEIGHT', '');
define('MODULE_SHIPPING_SASSI_TEXT_AMOUNT', '');

define('MODULE_SHIPPING_SASSI_TEXT_GET_QUOTE_LATER', '  <span class="calcLater">ϼ˻</span>');
?>
